PrintOnClickWidget | django_cradmin API Document

    import PrintOnClickWidget from 'django_cradmin/scripts/django_cradmin/widgets/PrintOnClickWidget.js'

public class | source

# PrintOnClickWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → PrintOnClickWidget

Run `window.print()` on click widget.

#### Example:

    <button type="button" data-ievv-jsbase-widget="cradmin-print-on-click">
        Print
    </button>

## Constructor Summary

Public Constructor
public | constructor(element: *) |

## Method Summary

Public Methods
public | destroy() |

## Public Constructors

### public constructor(element: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |

## Public Methods

### public destroy() source